@@ -341,6 +341,7 @@ _SPIRV_OP(UntypedInBoundsAccessChainKHR, 4420)
 _SPIRV_OP(UntypedPtrAccessChainKHR, 4423)
 _SPIRV_OP(UntypedInBoundsPtrAccessChainKHR, 4424)
 _SPIRV_OP(UntypedPrefetchKHR, 4426)
+_SPIRV_OP(FmaKHR, 4427)
 _SPIRV_OP(GroupNonUniformRotateKHR, 4431)
 _SPIRV_OP(SDotKHR, 4450)
 _SPIRV_OP(UDotKHR, 4451)
@@ -586,6 +587,7 @@ _SPIRV_OP(SpecConstantTargetINTEL, 6251)
 _SPIRV_OP(SpecConstantArchitectureINTEL, 6252)
 _SPIRV_OP(SpecConstantCapabilitiesINTEL, 6253)
 _SPIRV_OP(ConditionalCopyObjectINTEL, 6254)
+_SPIRV_OP(BitwiseFunctionINTEL, 6242)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
